// import the video library 
import processing.video.*;

// this is the video capturing object
Capture cam;

void setup() {
  // try 640 x 480 too
  size(320, 240);

  // use default camera (see 'video' demo and 
  // slides if this doesn't work) 
  cam = new Capture(this, 320, 240);
  cam.start();

  colorMode(HSB, 360, 100, 100, 100);
}


float trackHue = 0;
boolean showImage = true;

void draw() {

    if (showImage) {
      image(cam, 0, 0);
    } else {
      background(0);
    }

    cam.loadPixels();

    // position of closest hue
    int closestX = 0;
    int closestY = 0;
    // start closest distance to the hue very high
    float closestDist = 360;

    for (int y = 0; y < cam.height; y++) {
      for (int x = 0; x < cam.width; x++) {

        int i = x + y * cam.width;

        float b = brightness(cam.pixels[i]);
        float s = saturation(cam.pixels[i]);

        // get hue of current pixel
        float h = hue(cam.pixels[i]);
        // see how far it is from the hue we want to track
        // (abs is the absolute difference)
        float d = abs(trackHue - h); 

        // if it's closer that all the other pixels
        // and brightness and saturation are reasonable high
        // then update this as the closest pixel found so far
        if (d < closestDist && b > 50 && s > 50) {
          closestDist = d;
          closestX = x;
          closestY = y;
        }
      }
    }

    // draw shape at position that was closest
    fill(trackHue, 100, 100, 50);
    ellipse(closestX, closestY, 100, 100);
} 

// pick what colour to track
void mousePressed() {
  // get corresponding pixel in video frame
  int i = mouseX + mouseY * cam.width;
  // get that hue
  trackHue = hue(cam.pixels[i]);
}

void keyPressed() {
  // show or hide the frame
  showImage = !showImage;
}

// event function for video
// (called everytime there's a new frame)
void captureEvent(Capture cam) {
  cam.read();
}